# FILE: batchCtl.tcl
#
# PURPOSE:
# Control file for batch processing script doBatch.tcl
#
#   Author and copyright: 
#   T. Dijkhuis/H.v.d.Voort Scientific Volume Imaging Holding BV
#   Alexanderlaan 14,
#   1213 XS Hilversum,
#   The Netherlands,
#   email: info@svi.nl

# Set the compute environment The ConcurrentJobs parameter controls
# the number of jobs which are running at the same time. If 'auto' is
# selected this parameter is derived from the cpu count.  

# The ThreadsPerJob parameter controls the number of processors which
# work together on one job. If 'auto' is selected the number is
# derived from the number of ConcurrentJobs and the cpu count. Also
# 'auto' allows the number of threads per job to increase when there
# are less jobs in the queue left than the ConcurrentJobs number.  
#
set computeEnvironment(ConcurrentJobs) auto
set computeEnvironment(ThreadsPerJob) auto



# ----------------- The default microscopic parameters --------------------


set defaultMP(NumericalAperture) 1.3
set defaultMP(RefractiveIndexLensMedium) 1.515
set defaultMP(RefractiveIndexSpecimenMedium) 1.515
set defaultMP(ExcitationWavelength) 488.0
set defaultMP(EmissionWavelength) 520.0
set defaultMP(PhotonCount) 1
set defaultMP(PinholeSpacing) 2.53


# Unit system of lateral and axial sampling: micrometers
set defaultMP(LateralSampling) 0.05
set defaultMP(AxialSampling) 0.2 	 

# Unit system of backprojected pinhole radius: nanometers 
set defaultMP(PinholeRadius) 280	 

# The microscope type is a choice from confocal|widefield|4Pi|nipkow
set defaultMP(MicroscopeType) widefield	


# ----------------- The default restoration parameters -------------------

# Select the restoration method from: cmle or qmle
set defaultRP(Method) 		cmle

# If the background mode is lowest, object or wf a background value will
# be estimated for each channel and frame in the image. With the mode
# set to 'auto' the most appropriate method for the image is selected.
# The estimated values can be modified by a percentage in the range (-100..0..)
# as defined by the defaultRP(BackgroundPerc) field.
# If the background mode is 'manual' then the value in 'perc' is taken as an
# absolute value.
set defaultRP(BackgroundMode) 	auto
set defaultRP(BackgroundPerc) 	0.0

set defaultRP(SignalToNoise) 	30
set defaultRP(MaxIterations) 	100
set defaultRP(QualityCriterion) 0.1
# Padding can have values: auto | parent | padpar | fullpadpa
set defaultRP(Padding)          auto
# Set the maximum compute time for a task (seconds):
set defaultRP(Timeout)          3600




#   Define a microscopic parameter set
#   You can define as many as you like yourself
#
# If you use a MPSet, those parameters not specified here will be
# read from the defaultMP, except for ICS files: they  will be read from
# the files themselves.

set myMPSet(NumericalAperture)	1.30
set myMPSet(LateralSampling) 	0.065
set myMPSet(AxialSampling) 	0.1
set myMPSet(PinholeRadius)      {250 250 250}	
set myMPSet(ExcitationWavelength) {568 488.0 647}
set myMPSet(EmissionWavelength) {585 515 680}
set myMPSet(MicroscopeType) 	nipkow
set myMPSet(PinholeSpacing)   2.5


# Register it for future reference:
registerMPSet myMPSet 


# Define a few restoration parameter sets:
set myRPSet(Method) 		cmle
set myRPSet(SignalToNoise) 	{20 20 20}
set myRPSet(MaxIterations) 	50
set myRPSet(Timeout)            6000
set myRPSet(QualityCriterion)   0.01
set myRPSet(BackgroundMode) 	auto
set myRPSet(BackgroundPerc) 	{0 0 0}

# Register it for future reference:
registerRPSet  myRPSet 
 
# Define a few restoration parameter sets:
set myRPliveSet(Method) 		cmle
set myRPliveSet(SignalToNoise) 		30
set myRPliveSet(MaxIterations) 		100
set myRPliveSet(Timeout)            	6000
set myRPliveSet(QualityCriterion)   	0.01
set myRPliveSet(BackgroundMode) 	wf
# Register it for future reference:
registerRPSet  myRPliveSet 

set myOtherRPSet(SignalToNoise)     40
set myOtherRPSet(QualityCriterion)  0.01
set myOtherRPSet(Timeout)           1000
# Register it for future reference:
registerRPSet myOtherRPSet

set quickRunRPSet(Method) 		qmle
set quickRunRPSet(SignalToNoise) 	good
set quickRunRPSet(QualityCriterion) 	1.0
set quickRunRPSet(MaxIterations) 	10
set quickRunRPSet(BackgroundMode) 	lowest
set quickRunRPSet(BackgroundPerc) 	5
# Register it for future reference:
registerRPSet quickRunRPSet

#
# Set the project 'root' directory to which all image file pathnames are 
# relative:
#
setRootDirectory "/sidb/archive"

#In this path a directory "Results" will be created which will contain the deconvolved images.
setResultsPath "."

#setResultsPath "~/Huygens_Batch"

# Excluding files from selection.
#
# Sometimes 'glob' style pattern match selects too much files. File
# names matching the exlude pattern are removed from the list.
# Because square brackets have special meaning to Tcl the pattern is best 
# enclosed in curly braces.
# To disable this functionality use the keyword 'none'.
#
# Example:
# setExcludePattern {*[4-6].i*}
# to remove files like foo4.ics, faba5.ics
setExcludePattern {3418*}

#
# 			THE TASK QUEUE
#
# Each task consists of one or two filenames, a word indicating the method 
# to be used, two parameter sets and an optional double-quoted string 
# containing option-value pairs to be added to the image restoration command. 
#
# The items in a task are as follows:
#
# 1- The first word of the task is the filename of a measured image,
# 2- the name of the PSF (or 'auto' if it is unavailable),
# 3- a microscopic parameterset or '-' if you are sure the parameters in the
#    image file are fully correct,
# 4- a restoration parameterset,
#
# Example:
#
# addTask faba64.ics  auto myMPSet  myRPSet
#
# If you specify a MPSet, those parameters not specified there will be
# read from the defaultMP, except for ICS files: they will be read from
# the files themselves.
#
# You can use 'glob' style wildcards to select files.
# Example:
# foo*.ics will match fooBar.ics fooCell.ics, and so on.
#
# If 'glob' style pattern match selects too much files use the setExcludePattern
# command (see above).
#
# Note:
# Do NOT use wildcards in combination with numbered TIFF series in such a way
# that the wildcards can be confused with the index numbers.



#addTask 34*000*.tif  3419_rpsf_3418.ics  myMPSet  myRPSet
addTask 34*000*.tif 3449_rpsf_3418_3.ics myMPSet  myRPSet

